package dk.apaq.framework.repository;

/**
 *
 * @author michael
 */
public interface RepositoryListener<BT, IDT> {
    /**
     * Called before an entity is read.
     */
    void onBeforeEntityRead(RepositoryEvent.WithId<BT, IDT> event);

    /**
     * Called when an entity is read.
     */
    void onEntityRead(RepositoryEvent.WithIdAndEntity<BT, IDT> event);

    /**
     * Called before an entity is deleted.
     */
    void onBeforeEntityDelete(RepositoryEvent.WithId<BT, IDT> event);

    /**
     * Called when an entity is deleted.
     * @param event
     */
    void onEntityDelete(RepositoryEvent.WithId<BT, IDT> event);

    /**
     * Called before an entity is being persisted.
     */
    void onBeforeEntityUpdate(RepositoryEvent.WithIdAndEntity<BT, IDT> event);

    /**
     * Called when an entity is persisted.
     * @param event
     */
    void onEntityUpdate(RepositoryEvent.WithIdAndEntity<BT, IDT> event);

    /**
     * Called before an entity is created.
     */
    void onBeforeEntityCreate(RepositoryEvent.WithEntity<BT, IDT> event);

    /**
     * Called when an entity is created.
     */
    void onEntityCreate(RepositoryEvent.WithIdAndEntity<BT, IDT> event);
    
    /**
     * Called when ids or beans are being listed.
     */
    void onBeforeList(RepositoryEvent.List<BT, IDT> event);
}
